@@ -37,30 +37,26 @@
 class QTextBrowser;
 class QPushButton;
 
-namespace EventViews
-{
-
+namespace EventViews {
 class JournalFrame : public QFrame
 {
     Q_OBJECT
 public:
     typedef QList<JournalFrame *> List;
 
-    JournalFrame(const Akonadi::Item &journal,
-                 const Akonadi::ETMCalendar::Ptr &calendar,
-                 QWidget *parent);
+    JournalFrame(const Akonadi::Item &journal, const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent);
 
-    ~JournalFrame();
+    ~JournalFrame() override;
     bool eventFilter(QObject *, QEvent *) override;
 
     void setJournal(const Akonadi::Item &journal);
-    Akonadi::Item journal() const
+    Q_REQUIRED_RESULT Akonadi::Item journal() const
     {
         return mJournal;
     }
 
     void setCalendar(const Akonadi::ETMCalendar::Ptr &);
-    QDate date() const
+    Q_REQUIRED_RESULT QDate date() const
     {
         return mDate;
     }
@@ -80,10 +76,11 @@ public Q_SLOTS:
     {
         mChanger = changer;
     }
+
     void setDate(const QDate &date);
 
 Q_SIGNALS:
-    void printJournal(const KCalCore::Journal::Ptr &, bool preview);
+    void printJournal(const KCalendarCore::Journal::Ptr &, bool preview);
     void deleteIncidence(const Akonadi::Item &);
     void editIncidence(const Akonadi::Item &);
     void incidenceSelected(const Akonadi::Item &, const QDate &);
@@ -96,15 +93,15 @@ private:
     Akonadi::ETMCalendar::Ptr mCalendar;
     QDate mDate;
 
-    QTextBrowser *mBrowser;
-    QPushButton *mEditButton;
-    QPushButton *mDeleteButton;
-    QPushButton *mPrintButton;
-    QPushButton *mPrintPreviewButton;
+    QTextBrowser *mBrowser = nullptr;
+    QPushButton *mEditButton = nullptr;
+    QPushButton *mDeleteButton = nullptr;
+    QPushButton *mPrintButton = nullptr;
+    QPushButton *mPrintPreviewButton = nullptr;
 
     bool mDirty;
     bool mWriteInProgress;
-    Akonadi::IncidenceChanger *mChanger;
+    Akonadi::IncidenceChanger *mChanger = nullptr;
 };
 
 class JournalDateView : public QFrame
@@ -135,7 +132,7 @@ Q_SIGNALS:
     void deleteIncidence(const Akonadi::Item &journal);
     void newJournal(const QDate &);
     void incidenceSelected(const Akonadi::Item &, const QDate &);
-    void printJournal(const KCalCore::Journal::Ptr &, bool preview);
+    void printJournal(const KCalendarCore::Journal::Ptr &, bool preview);
 
 public Q_SLOTS:
     void emitNewJournal();
@@ -148,9 +145,8 @@ private:
     QDate mDate;
     QMap<Akonadi::Item::Id, JournalFrame *> mEntries;
 
-    Akonadi::IncidenceChanger *mChanger;
+    Akonadi::IncidenceChanger *mChanger = nullptr;
 };
-
 }
 
 #endif
